
local QuestAnnounce = LibStub("AceAddon-3.0"):GetAddon("QuestAnnounce")
local L = LibStub("AceLocale-3.0"):GetLocale("QuestAnnounce")

local options, configOptions = nil, {}
--[[ This options table is used in the GUI config. ]]-- 
local function getOptions() 
	if not options then
		options = {
		    type = "group",
			name ="QuestAnnounce",			
		    args = {
				settings = {
					order = 1,
					inline = true,
					type = "group",
					name = L["Settings"],
					get = function(info)
						local key = info.arg or info[#info]
						QuestAnnounce:SendDebugMsg("getOption: "..key.." :: "..tostring(QuestAnnounce.db.profile[key]))
						return QuestAnnounce.db.profile[key]
					end,
					set = function(info, value)
						local key = info.arg or info[#info]
						QuestAnnounce.db.profile[key] = value
						QuestAnnounce:SendDebugMsg("setOption: "..key.." :: "..tostring(QuestAnnounce.db.profile[key]))
					end,					
					args = {
						
						enabledesc = {
							order = 1,
							type = "description",
							fontSize = "medium",
							name = L["Enables/Disables Quest Announce"]
						},
						enable = {
							order = 2,
							type = "toggle",
							name = L["Enable"],
				        },
						everydesc = {
							order = 3,
							type = "description",
							fontSize = "medium",
							name = L["Announce progression every x number of steps (0 will announce on quest objective completion only)"]
						},
						every = {
							order = 4,
							type = "range",
							name = L["Announce Every"],
							min = 0,
							max = 10,
							step = 1
				        },
						announce = {
							order = 6,
							type = "group",
							inline = true,
							name = L["Announce In"],
							get = function(info)
								local key = info.arg or info[#info]
								QuestAnnounce:SendDebugMsg("getAnnounce: "..key.." :: "..tostring(QuestAnnounce.db.profile.announce[key]))
								return QuestAnnounce.db.profile.announce[key]
							end,
							set = function(info, value)
								local key = info.arg or info[#info]
								QuestAnnounce.db.profile.announce[key] = value
								QuestAnnounce:SendDebugMsg("setAnnounce: "..key.." :: "..tostring(QuestAnnounce.db.profile.announce[key]))
							end,
							args = {
								say = {
									order = 1,
									type = "toggle",
									name = L["Say"]
								},
								party = {
									order = 2,
									type = "toggle",
									name = L["Party"]
								},
								guild = {
									order = 3,
									type = "toggle",
									name = L["Guild"],
									confirm = function(info, value)
										return (value and L["Are you sure you want to announce to this channel?"] or false)
									end									
								},
								officer = {
									order = 4,
									type = "toggle",
									name = L["Officer"],
									confirm = function(info, value)
										return (value and L["Are you sure you want to announce to this channel?"] or false)
									end
								},
								whisper = {
									order = 7,
									type = "toggle",
									name = L["Whisper"],
									confirm = function(info, value)
										return (value and L["Are you sure you want to announce to this channel?"] or false)
									end
								},
								whisperWho = {
									order = 8,
									type = "input",
									name = L["Whisper Who"]
								},																
							}
						},
						debugdesc = {
							order = 7,
							type = "description",
							fontSize = "medium",							
							name = L["Enables/Disables Quest Announce Debug Mode"]
						},
						debug = {
							order = 8,
							type = "toggle",
							name = L["Debug"]
				        }
					}
				}
		    }
		}
		for k,v in pairs(configOptions) do
			options.args[k] = (type(v) == "function") and v() or v
		end
	end
	
	return options
end

local function openConfig() 
	InterfaceOptionsFrame_OpenToCategory(QuestAnnounce.optionsFrames.Profiles)
	InterfaceOptionsFrame_OpenToCategory(QuestAnnounce.optionsFrames.QuestAnnounce)
	InterfaceOptionsFrame:Raise()
end

function QuestAnnounce:SetupOptions()
	self.optionsFrames = {}

	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("QuestAnnounce", getOptions)
	self.optionsFrames.QuestAnnounce = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("QuestAnnounce", nil, nil, "settings")

	configOptions["Profiles"] = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)

	self.optionsFrames["Profiles"] = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("QuestAnnounce", "Profiles", "QuestAnnounce", "Profiles")

	LibStub("AceConsole-3.0"):RegisterChatCommand("qa", openConfig)
end